Struct Ccgr4
Source #[repr(transparent)]
pub struct Ccgr4(pub u32);
CCM Clock Gating Register 4
sim_m7 register access clock (sim_m7_mainclk_r_enable)
sim_m7 register access clock (sim_m7_mainclk_r_enable)
iomuxc clock (iomuxc_clk_enable)
iomuxc clock (iomuxc_clk_enable)
iomuxc gpr clock (iomuxc_gpr_clk_enable)
iomuxc gpr clock (iomuxc_gpr_clk_enable)
bee clock(bee_clk_enable)
bee clock(bee_clk_enable)
sim_m7 clock (sim_m7_clk_enable)
sim_m7 clock (sim_m7_clk_enable)
tsc_dig clock (tsc_clk_enable)
tsc_dig clock (tsc_clk_enable)
sim_m clocks (sim_m_clk_enable)
sim_m clocks (sim_m_clk_enable)
sim_ems clocks (sim_ems_clk_enable)
sim_ems clocks (sim_ems_clk_enable)
pwm1 clocks (pwm1_clk_enable)
pwm1 clocks (pwm1_clk_enable)
pwm2 clocks (pwm2_clk_enable)
pwm2 clocks (pwm2_clk_enable)
pwm3 clocks (pwm3_clk_enable)
pwm3 clocks (pwm3_clk_enable)
pwm4 clocks (pwm4_clk_enable)
pwm4 clocks (pwm4_clk_enable)
qdc1 clocks (qdc1_clk_enable)
qdc1 clocks (qdc1_clk_enable)
qdc2 clocks (qdc2_clk_enable)
qdc2 clocks (qdc2_clk_enable)
qdc3 clocks (qdc3_clk_enable)
qdc3 clocks (qdc3_clk_enable)
qdc4 clocks (qdc4_clk_enable)
qdc4 clocks (qdc4_clk_enable)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.