Struct Ccgr6
Source #[repr(transparent)]
pub struct Ccgr6(pub u32);
CCM Clock Gating Register 6
usboh3 clock (usboh3_clk_enable)
usboh3 clock (usboh3_clk_enable)
usdhc1 clocks (usdhc1_clk_enable)
usdhc1 clocks (usdhc1_clk_enable)
usdhc2 clocks (usdhc2_clk_enable)
usdhc2 clocks (usdhc2_clk_enable)
dcdc clocks (dcdc_clk_enable)
dcdc clocks (dcdc_clk_enable)
ipmux4 clock (ipmux4_clk_enable)
ipmux4 clock (ipmux4_clk_enable)
flexspi clocks (flexspi_clk_enable) sim_ems_clk_enable must also be cleared, when flexspi_clk_enable is cleared
flexspi clocks (flexspi_clk_enable) sim_ems_clk_enable must also be cleared, when flexspi_clk_enable is cleared
trng clock (trng_clk_enable)
trng clock (trng_clk_enable)
lpuart8 clocks (lpuart8_clk_enable)
lpuart8 clocks (lpuart8_clk_enable)
timer4 clocks (timer4_clk_enable)
timer4 clocks (timer4_clk_enable)
aips_tz3 clock (aips_tz3_clk_enable)
aips_tz3 clock (aips_tz3_clk_enable)
anadig clocks (anadig_clk_enable)
anadig clocks (anadig_clk_enable)
lpi2c4 serial clock (lpi2c4_serial_clk_enable)
lpi2c4 serial clock (lpi2c4_serial_clk_enable)
timer1 clocks (timer1_clk_enable)
timer1 clocks (timer1_clk_enable)
timer2 clocks (timer2_clk_enable)
timer2 clocks (timer2_clk_enable)
timer3 clocks (timer3_clk_enable)
timer3 clocks (timer3_clk_enable)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.