nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ccr

Struct Ccr 

#[repr(transparent)]
pub struct Ccr(pub u32);
CCM Control Register

Tuple Fields

0: u32

Implementations

Source

impl Ccr

pub const fn oscnt(&self) -> u8

Oscillator ready counter value. These bits define value of 32KHz counter, that serve as counter for oscillator lock time (count to n+1 ckil’s). This is used for oscillator lock time. Current estimation is ~5ms. This counter will be used in ignition sequence and in wake from stop sequence if sbyos bit was defined, to notify that on chip oscillator output is ready for the dpll_ip to use and only then the gate in dpll_ip can be opened.

pub const fn set_oscnt(&mut self, val: u8)

Oscillator ready counter value. These bits define value of 32KHz counter, that serve as counter for oscillator lock time (count to n+1 ckil’s). This is used for oscillator lock time. Current estimation is ~5ms. This counter will be used in ignition sequence and in wake from stop sequence if sbyos bit was defined, to notify that on chip oscillator output is ready for the dpll_ip to use and only then the gate in dpll_ip can be opened.

pub const fn cosc_en(&self) -> CoscEn

On chip oscillator enable bit - this bit value is reflected on the output cosc_en

pub const fn set_cosc_en(&mut self, val: CoscEn)

On chip oscillator enable bit - this bit value is reflected on the output cosc_en

pub const fn reg_bypass_count(&self) -> RegBypassCount

Counter for analog_reg_bypass signal assertion after standby voltage request by PMIC_STBY_REQ

pub const fn set_reg_bypass_count(&mut self, val: RegBypassCount)

Counter for analog_reg_bypass signal assertion after standby voltage request by PMIC_STBY_REQ

pub const fn rbc_en(&self) -> RbcEn

Enable for REG_BYPASS_COUNTER

pub const fn set_rbc_en(&mut self, val: RbcEn)

Enable for REG_BYPASS_COUNTER