nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ccsr

Struct Ccsr 

#[repr(transparent)]
pub struct Ccsr(pub u32);
CCM Clock Switcher Register

Tuple Fields

0: u32

Implementations

Source

impl Ccsr

pub const fn pll3_sw_clk_sel(&self) -> Pll3SwClkSel

Selects source to generate pll3_sw_clk. This bit should only be used for testing purposes.

pub const fn set_pll3_sw_clk_sel(&mut self, val: Pll3SwClkSel)

Selects source to generate pll3_sw_clk. This bit should only be used for testing purposes.