nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cimr

Struct Cimr 

#[repr(transparent)]
pub struct Cimr(pub u32);
CCM Interrupt Mask Register

Tuple Fields

0: u32

Implementations

Source

impl Cimr

pub const fn mask_lrf_pll(&self) -> MaskLrfPll

mask interrupt generation due to lrf of PLLs

pub const fn set_mask_lrf_pll(&mut self, val: MaskLrfPll)

mask interrupt generation due to lrf of PLLs

pub const fn mask_cosc_ready(&self) -> MaskCoscReady

mask interrupt generation due to on board oscillator ready

pub const fn set_mask_cosc_ready(&mut self, val: MaskCoscReady)

mask interrupt generation due to on board oscillator ready

pub const fn mask_semc_podf_loaded(&self) -> MaskSemcPodfLoaded

mask interrupt generation due to frequency change of semc_podf

pub const fn set_mask_semc_podf_loaded(&mut self, val: MaskSemcPodfLoaded)

mask interrupt generation due to frequency change of semc_podf

pub const fn mask_periph2_clk_sel_loaded(&self) -> MaskPeriph2ClkSelLoaded

mask interrupt generation due to update of periph2_clk_sel.

pub const fn set_mask_periph2_clk_sel_loaded( &mut self, val: MaskPeriph2ClkSelLoaded, )

mask interrupt generation due to update of periph2_clk_sel.

pub const fn mask_ahb_podf_loaded(&self) -> MaskAhbPodfLoaded

mask interrupt generation due to frequency change of ahb_podf

pub const fn set_mask_ahb_podf_loaded(&mut self, val: MaskAhbPodfLoaded)

mask interrupt generation due to frequency change of ahb_podf

pub const fn mask_periph_clk_sel_loaded(&self) -> MaskPeriphClkSelLoaded

mask interrupt generation due to update of periph_clk_sel.

pub const fn set_mask_periph_clk_sel_loaded( &mut self, val: MaskPeriphClkSelLoaded, )

mask interrupt generation due to update of periph_clk_sel.

pub const fn arm_podf_loaded(&self) -> CimrArmPodfLoaded

mask interrupt generation due to frequency change of arm_podf

pub const fn set_arm_podf_loaded(&mut self, val: CimrArmPodfLoaded)

mask interrupt generation due to frequency change of arm_podf