nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Clpcr

Struct Clpcr 

#[repr(transparent)]
pub struct Clpcr(pub u32);
CCM Low Power Control Register

Tuple Fields

0: u32

Implementations

Source

impl Clpcr

pub const fn lpm(&self) -> Lpm

Setting the low power mode that system will enter on next assertion of dsm_request signal.

pub const fn set_lpm(&mut self, val: Lpm)

Setting the low power mode that system will enter on next assertion of dsm_request signal.

pub const fn arm_clk_dis_on_lpm(&self) -> ArmClkDisOnLpm

Define if Arm clocks (arm_clk, soc_mxclk, soc_pclk, soc_dbg_pclk, vl_wrck) will be disabled on wait mode

pub const fn set_arm_clk_dis_on_lpm(&mut self, val: ArmClkDisOnLpm)

Define if Arm clocks (arm_clk, soc_mxclk, soc_pclk, soc_dbg_pclk, vl_wrck) will be disabled on wait mode

pub const fn sbyos(&self) -> Sbyos

Standby clock oscillator bit

pub const fn set_sbyos(&mut self, val: Sbyos)

Standby clock oscillator bit

pub const fn dis_ref_osc(&self) -> DisRefOsc

dis_ref_osc - in run mode, software can manually control closing of external reference oscillator clock, i

pub const fn set_dis_ref_osc(&mut self, val: DisRefOsc)

dis_ref_osc - in run mode, software can manually control closing of external reference oscillator clock, i

pub const fn vstby(&self) -> Vstby

Voltage standby request bit

pub const fn set_vstby(&mut self, val: Vstby)

Voltage standby request bit

pub const fn stby_count(&self) -> StbyCount

Standby counter definition

pub const fn set_stby_count(&mut self, val: StbyCount)

Standby counter definition

pub const fn cosc_pwrdown(&self) -> CoscPwrdown

In run mode, software can manually control powering down of on chip oscillator, i

pub const fn set_cosc_pwrdown(&mut self, val: CoscPwrdown)

In run mode, software can manually control powering down of on chip oscillator, i

pub const fn bypass_lpm_hs1(&self) -> bool

Bypass low power mode handshake. This bit should always be set to 1’b1 by software.

pub const fn set_bypass_lpm_hs1(&mut self, val: bool)

Bypass low power mode handshake. This bit should always be set to 1’b1 by software.

pub const fn bypass_lpm_hs0(&self) -> bool

Bypass low power mode handshake. This bit should always be set to 1’b1 by software.

pub const fn set_bypass_lpm_hs0(&mut self, val: bool)

Bypass low power mode handshake. This bit should always be set to 1’b1 by software.

pub const fn mask_core0_wfi(&self) -> MaskCore0Wfi

Mask WFI of core0 for entering low power mode Assertion of all bits[27:22] will generate low power mode request

pub const fn set_mask_core0_wfi(&mut self, val: MaskCore0Wfi)

Mask WFI of core0 for entering low power mode Assertion of all bits[27:22] will generate low power mode request

pub const fn mask_scu_idle(&self) -> MaskScuIdle

Mask SCU IDLE for entering low power mode Assertion of all bits[27:22] will generate low power mode request

pub const fn set_mask_scu_idle(&mut self, val: MaskScuIdle)

Mask SCU IDLE for entering low power mode Assertion of all bits[27:22] will generate low power mode request

pub const fn mask_l2cc_idle(&self) -> MaskL2ccIdle

Mask L2CC IDLE for entering low power mode

pub const fn set_mask_l2cc_idle(&mut self, val: MaskL2ccIdle)

Mask L2CC IDLE for entering low power mode