nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cs1cdr

Struct Cs1cdr 

#[repr(transparent)]
pub struct Cs1cdr(pub u32);
CCM Clock Divider Register

Tuple Fields

0: u32

Implementations

Source

impl Cs1cdr

pub const fn sai1_clk_podf(&self) -> Sai1ClkPodf

Divider for sai1 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.

pub const fn set_sai1_clk_podf(&mut self, val: Sai1ClkPodf)

Divider for sai1 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.

pub const fn sai1_clk_pred(&self) -> Sai1ClkPred

Divider for sai1 clock pred.

pub const fn set_sai1_clk_pred(&mut self, val: Sai1ClkPred)

Divider for sai1 clock pred.

pub const fn flexio2_clk_pred(&self) -> Flexio2ClkPred

Divider for flexio2/flexio3 clock.

pub const fn set_flexio2_clk_pred(&mut self, val: Flexio2ClkPred)

Divider for flexio2/flexio3 clock.

pub const fn sai3_clk_podf(&self) -> Sai3ClkPodf

Divider for sai3 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.

pub const fn set_sai3_clk_podf(&mut self, val: Sai3ClkPodf)

Divider for sai3 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.

pub const fn sai3_clk_pred(&self) -> Sai3ClkPred

Divider for sai3/adc1/adc2 clock pred.

pub const fn set_sai3_clk_pred(&mut self, val: Sai3ClkPred)

Divider for sai3/adc1/adc2 clock pred.

pub const fn flexio2_clk_podf(&self) -> Flexio2ClkPodf

Divider for flexio2/flexio3 clock. Divider should be updated when output clock is gated.

pub const fn set_flexio2_clk_podf(&mut self, val: Flexio2ClkPodf)

Divider for flexio2/flexio3 clock. Divider should be updated when output clock is gated.