nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Cs2cdr

Struct Cs2cdr 

#[repr(transparent)]
pub struct Cs2cdr(pub u32);
CCM Clock Divider Register

Tuple Fields

0: u32

Implementations

Source

impl Cs2cdr

pub const fn sai2_clk_podf(&self) -> Sai2ClkPodf

Divider for sai2 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.

pub const fn set_sai2_clk_podf(&mut self, val: Sai2ClkPodf)

Divider for sai2 clock podf. The input clock to this divider should be lower than 300Mhz, the predivider can be used to achieve this.

pub const fn sai2_clk_pred(&self) -> Sai2ClkPred

Divider for sai2 clock pred.Divider should be updated when output clock is gated.

pub const fn set_sai2_clk_pred(&mut self, val: Sai2ClkPred)

Divider for sai2 clock pred.Divider should be updated when output clock is gated.