#[repr(transparent)]pub struct Cscdr3(pub u32);Expand description
CCM Serial Clock Divider Register 3
Tuple Fields
0: u32Implementations
Sourceimpl Cscdr3
impl Cscdr3
Sourcepub const fn csi_clk_sel(&self) -> CsiClkSel
pub const fn csi_clk_sel(&self) -> CsiClkSel
Selector for csi_mclk multiplexer
Sourcepub const fn set_csi_clk_sel(&mut self, val: CsiClkSel)
pub const fn set_csi_clk_sel(&mut self, val: CsiClkSel)
Selector for csi_mclk multiplexer
Sourcepub const fn csi_podf(&self) -> CsiPodf
pub const fn csi_podf(&self) -> CsiPodf
Post divider for csi_mclk. Divider should be updated when output clock is gated.
Sourcepub const fn set_csi_podf(&mut self, val: CsiPodf)
pub const fn set_csi_podf(&mut self, val: CsiPodf)
Post divider for csi_mclk. Divider should be updated when output clock is gated.